@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ARP / RARP header information
 **
-** $Id: arp.c,v 1.14 2001/04/02 17:41:01 mborella Exp $
+** $Id: arp.c,v 1.17 2001/05/18 21:54:16 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
 #include "arp.h"
 #include "ethertypes.h"
 
+#define ARP_PADDING_SIZE 18 /* bytes to pad ARP to the min eth frame len */
+
 /*
  * ARP opcode map
  */
@@ -97,15 +99,19 @@ void dump_etherarp(packet_t *pkt)
       }
   
   /*
-   * Some ARPs include Ethernet frame padding.  Check for that.
+   * Some ARPs include Ethernet frame padding.  Check for that.  Note that we
+   * must allow ARP frames to be 1500 bytes.  Some NICs seems to generate 
+   * them as such.  Strange but true.
    */
 
  if (!my_args->m && !my_args->n)
    {
-     u_int8_t padding[32];
+     u_int8_t padding[ARP_PADDING_SIZE]; 
      int bytes;
 
      bytes = get_packet_bytesleft(pkt); 
+     if (bytes > ARP_PADDING_SIZE)
+       bytes = ARP_PADDING_SIZE;
      if (!bytes || (get_packet_bytes((u_int8_t *) &padding, pkt, bytes) == 0))
        return;
      display("Padding", (u_int8_t *) &padding, bytes, DISP_HEX_MULTILINE);
