@@ -5,7 +5,7 @@
 **
 ** Comments: Displaying functions
 **
-** $Id: display.c,v 1.20 2000/10/17 16:35:37 mborella Exp $
+** $Id: display.c,v 1.22 2001/05/18 21:54:16 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,10 +25,11 @@
 
 #include "display.h"
 
-#define LABEL_LENGTH     22
-#define MULTILINE_LENGTH 23
-#define BUF_SIZE         128
-#define HOLDER_LEN       64
+#define LABEL_LENGTH            22
+#define MULTILINE_LENGTH        23
+#define MULTILINE_STRING_LENGTH 50
+#define BUF_SIZE                128
+#define HOLDER_LEN              64
 
 int packet_displayed;
 int start_of_packet;
@@ -231,6 +232,7 @@ inline void display_minimal(u_int8_t * content, u_int8_t length,
   u_int8_t       * temp;
   double           sum;
   u_int32_t        multiplier;
+  int              len;
 
   /*
    * We have displayed part of this packet, so we need a carriage return.
@@ -356,12 +358,20 @@ inline void display_minimal(u_int8_t * content, u_int8_t length,
       memcpy(ptr, content, length);
       ptr[length] = '\0';
 
+      /* Clean out extra control characters */
+      len = strlen(ptr);
+      while((ptr[len-1] == '\n' || ptr[len-1] == '\r') && len >= 1)
+	{
+	  ptr[len-1] = '\0';
+	  len--;
+	}
+
       /* 
        * Let's make sure that the string contains only printable
        * characters
        */
       
-      if (!isprint_str(ptr, length))
+      if (!isprint_str(ptr, len))
 	{
 	  my_free(ptr);
 	  break;
@@ -372,6 +382,18 @@ inline void display_minimal(u_int8_t * content, u_int8_t length,
       my_free(ptr);
       break;
 
+    case DISP_STRING_MULTILINE:
+      for (i=0; i < length; i++)
+	{
+	  if ((i > 0) && (i % MULTILINE_STRING_LENGTH == 0))
+	    {
+	      printf("\n");
+	      display_whitespace_pad(-3);
+	    }
+	  printf("%c", content[i]);
+	}
+      break;
+
     default: /* oops, this shouldn't happen... */
     }
 }
