@@ -5,7 +5,7 @@
 **
 ** Comments: 
 **
-** $Id: gre.c,v 1.8 2001/04/02 17:41:01 mborella Exp $
+** $Id: gre.c,v 1.9 2001/04/26 23:49:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -218,13 +218,15 @@ void dump_gre(packet_t *pkt)
 			== 0)
 		      return;
 		    checksum = ntohs(checksum);
-		    display("Checksum", (u_int8_t *) &checksum, 2, DISP_DEC);
+		    if (!my_args->m)
+		      display("Checksum", (u_int8_t *) &checksum, 2, DISP_DEC);
 
 		    if (get_packet_bytes((u_int8_t *) &offset, pkt, 2)
 			== 0)
 		      return;
 		    offset = ntohs(offset);
-		    display("Offset", (u_int8_t *) &offset, 2, DISP_DEC);
+		    if (!my_args->m)
+		      display("Offset", (u_int8_t *) &offset, 2, DISP_DEC);
 		  }
 	      }
 
@@ -238,7 +240,8 @@ void dump_gre(packet_t *pkt)
 		    if (get_packet_bytes((u_int8_t *) &key, pkt, 4) == 0)
 		      return;
 		    key = ntohl(key);
-		    display("Key", (u_int8_t *) &key, 4, DISP_DEC);
+		    if (!my_args->m)
+		      display("Key", (u_int8_t *) &key, 4, DISP_DEC);
 		  }
 	      }
 
@@ -252,8 +255,9 @@ void dump_gre(packet_t *pkt)
 		    if (get_packet_bytes((u_int8_t *) &seqno, pkt, 4) == 0)
 		      return;
 		    seqno = ntohl(seqno);
-		    display("Sequence number", (u_int8_t *) &seqno, 4, 
-			    DISP_DEC);
+		    if (!my_args->m)
+		      display("Sequence number", (u_int8_t *) &seqno, 4, 
+			      DISP_DEC);
 		  }
 	      }
 	    
@@ -267,7 +271,8 @@ void dump_gre(packet_t *pkt)
 		    if (get_packet_bytes((u_int8_t *) &routing, pkt, 4) == 0)
 		      return;
 		    routing = ntohs(routing);
-		    display("Routing", (u_int8_t *) &routing, 4, DISP_DEC);
+		    if (!my_args->m)
+		      display("Routing", (u_int8_t *) &routing, 4, DISP_DEC);
 		  }
 	      }
 	  }
