@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ICMP information
 **
-** $Id: icmp.c,v 1.13 2001/01/20 00:30:31 mborella Exp $
+** $Id: icmp.c,v 1.14 2001/04/02 17:41:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -277,6 +277,12 @@ void dump_icmp(packet_t *pkt)
   icmp_header_t icmp;
   char holder[64];
 
+  /*
+   * Stats accounting
+   */
+
+  stats_update(STATS_ICMP);
+
   /*
    * Get the header
    */
