@@ -7,7 +7,7 @@
 ** Sniffs all packets on the link and dumps the fields of the data link, 
 ** IP, TCP, and UDP headers.  
 **
-** $Id: ipgrab.c,v 1.11 2000/11/07 19:46:09 mborella Exp $
+** $Id: ipgrab.c,v 1.14 2001/04/02 23:18:28 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,12 +31,15 @@
 #include "open_pcap.h"
 #include "ip_protocols.h"
 #include "error.h"
+#include "stats.h"
+#include "dynports.h"
 
-char         * pcap_cmd;  /* command string for pcap */
-pcap_t       * pd;        /* pcap device descriptor */
-int            cnt;       /* number of packets to read */
-pcap_handler   dev_prcsr; /* ptr to func that processes packet for a device */
-struct arg_t * my_args;   /* Command line arguments */
+char          * pcap_cmd;  /* command string for pcap */
+pcap_t        * pd;        /* pcap device descriptor */
+int             cnt;       /* number of packets to read */
+pcap_handler    dev_prcsr; /* ptr to func that processes packet for a device */
+pcap_dumper_t * p;         /* pointer to pcap dump file for writing */
+struct arg_t  * my_args;   /* Command line arguments */
 
 RETSIGTYPE do_stats(void);
 
@@ -53,10 +56,11 @@ int main(int argc, char *argv[])
   int link;
 
   /*
-   * Initiatilize the IP family module
+   * Initiatilize the IP family module and the stats collection module
    */
 
   init_ip_protocols();
+  stats_init();
 
   /*
    * Clear packet count
@@ -83,6 +87,12 @@ int main(int argc, char *argv[])
   setvbuf(stdout, NULL, _IOLBF, 0);
 #endif
 
+  /*
+   * Parse any dynamic port bindings
+   */
+  
+  if (my_args->P)
+    dynports_parse(my_args->P);
   
   /* 
    * Copy filter command into a string only if there is a command
@@ -155,12 +165,27 @@ int main(int argc, char *argv[])
   signal(SIGQUIT, (sighandler_t) do_stats);
   signal(SIGABRT, (sighandler_t) do_stats);
 
-  /*
-   * Read all packets on the device.  Continue until cnt packets read 
+  /* 
+   * Open the file for writing if -w is used 
    */
-  
-  if (pcap_loop(pd, cnt, (pcap_func_t) datalink, userdata) < 0)
-    error_fatal("pcap_loop: %s", pcap_geterr(pd));
+
+  if (my_args->w)
+    {
+      p = pcap_dump_open(pd, my_args->w);
+      if (p == NULL)
+	error_system("pcap_dump_open: %s", pcap_geterr(pd));
+
+      /* Read the specified number of packets */
+      if (pcap_loop(pd, cnt, pcap_dump, (u_char *) p) < 0)
+	error_fatal("pcap_loop: %s", pcap_geterr(pd));
+    }
+  else
+    {
+      /* Read all packets on the device.  Continue until cnt packets read */
+      
+      if (pcap_loop(pd, cnt, (pcap_func_t) datalink, userdata) < 0)
+	error_fatal("pcap_loop: %s", pcap_geterr(pd));
+    }
 
   do_stats();
 
@@ -188,13 +213,26 @@ RETSIGTYPE do_stats(void)
       fprintf(stderr, "%d packets received\n", stats.ps_recv);
       fprintf(stderr, "%d packets dropped by kernel\n", stats.ps_drop);
     }
-  
+
+  /*
+   * Dump out the stats
+   */
+
+  stats_dump();
+
   /*
    * Close the pcap device
    */
 
   pcap_close(pd);
 
+  /*
+   * If there was a dump file open for writing, close that too 
+   */
+  
+  if (my_args->w)
+    pcap_dump_close(p);
+
   exit(0);
 }
 
