@@ -13,7 +13,7 @@
 ** and when you can't find the value anywhere else, look in:
 ** draft-ietf-ipsec-ike-01 "The Internet Key Exchange (IKE)"
 **
-** $Id: isakmp.c,v 1.8 2000/11/07 19:46:09 mborella Exp $
+** $Id: isakmp.c,v 1.9 2001/03/27 20:45:36 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -951,8 +951,6 @@ void dump_isakmp(packet_t * pkt)
 
   if (next == ISAKMP_PAYLOAD_NONE || e_flag)
     {
-      if (my_args->p && get_packet_bytesleft(pkt)) 
-	dump_payload(pkt);
       return;
     }
 
