@@ -5,7 +5,7 @@
 **
 ** Comments: 
 **
-** $Id: mobileip.c,v 1.7 2001/04/02 23:18:28 mborella Exp $
+** $Id: mobileip.c,v 1.8 2001/04/26 23:49:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -302,7 +302,8 @@ void dump_mobileip_ext_sessionspecific(packet_t *pkt)
   /* Display */
   if (my_args->m)
     {
-
+      display_minimal_string(map2str(mobileip_ext_map, ss.type));
+      display_minimal_string(" ");
     }
   else
     {
@@ -376,7 +377,8 @@ void dump_mobileip_ext_cvse(packet_t * pkt)
   /* Display */
   if (my_args->m)
     {
-
+      display_minimal_string(map2str(mobileip_ext_map, cvse.type));
+      display_minimal_string(" ");
     }
   else
     {
@@ -436,7 +438,8 @@ void dump_mobileip_ext_mhauth(packet_t * pkt)
   /* Display */
   if (my_args->m)
     {
-
+      display_minimal_string(map2str(mobileip_ext_map, mh.type));
+      display_minimal_string(" ");
     }
   else
     {
@@ -473,6 +476,19 @@ void dump_mobileip(packet_t *pkt)
   if (look_packet_bytes(&first_byte, pkt, 1) == 0)
     return;
 
+  /* 
+   * Display mobile IP annoucnement
+   */
+
+  if (my_args->m)
+    display_minimal_string("| Mobile IP ");
+  else
+    display_header_banner("Mobile IP");
+
+  /* 
+   * Take action based on message type
+   */
+
   switch(first_byte)
     {
     case MOBILEIP_TYPE_REGREQ: /* registration request */
@@ -489,12 +505,18 @@ void dump_mobileip(packet_t *pkt)
 	/* Display */
 	if (my_args->m)
 	  {
-
+	    display_minimal_string(map2str(mobileip_type_map, regreq.type));
+	    display_minimal_string(" (");
+	    display_minimal_string("addr:");
+	    display_minimal_ipv4((u_int8_t *) &regreq.home_addr);
+	    display_minimal_string(",HA:");
+	    display_minimal_ipv4((u_int8_t *) &regreq.home_agent);
+	    display_minimal_string(",COA:");
+	    display_minimal_ipv4((u_int8_t *) &regreq.care_of_addr);
+	    display_minimal_string(") ");
 	  }
 	else
 	  {
-	    display_header_banner("Mobile IP");
-
 	    display_strmap("Type", regreq.type, mobileip_type_map);
 	    display("Flags", &regreq.flags, 1, DISP_HEX);
 	    display("Lifetime", (u_int8_t *) &regreq.lifetime, 2, DISP_DEC);
@@ -521,12 +543,16 @@ void dump_mobileip(packet_t *pkt)
 	/* Display */
 	if (my_args->m)
 	  {
-
+	    display_minimal_string(map2str(mobileip_type_map, regrep.type));
+	    display_minimal_string(" (");
+	    display_minimal_string("addr:");
+	    display_minimal_ipv4((u_int8_t *) &regrep.home_addr);
+	    display_minimal_string(",HA:");
+	    display_minimal_ipv4((u_int8_t *) &regrep.home_agent);
+	    display_minimal_string(") ");
 	  }
 	else
 	  {
-	    display_header_banner("Mobile IP");
-
 	    display_strmap("Type", regrep.type, mobileip_type_map);
 	    display("Code", &regrep.code, 1, DISP_HEX);
 	    display("Lifetime", (u_int8_t *) &regrep.lifetime, 2, DISP_DEC);
@@ -550,12 +576,16 @@ void dump_mobileip(packet_t *pkt)
 	/* Display */
 	if (my_args->m)
 	  {
-
+	    display_minimal_string(map2str(mobileip_type_map, regupdate.type));
+	    display_minimal_string(" (");
+	    display_minimal_string("addr:");
+	    display_minimal_ipv4((u_int8_t *) &regupdate.home_addr);
+	    display_minimal_string(",HA:");
+	    display_minimal_ipv4((u_int8_t *) &regupdate.home_agent);
+	    display_minimal_string(") ");
 	  }
 	else
 	  {
-	    display_header_banner("Mobile IP");
-
 	    display_strmap("Type", regupdate.type, mobileip_type_map);
 	    display("Reserved", (u_int8_t *) &regupdate.reserved, 3, DISP_DEC);
 	    display_ipv4("Home address", (u_int8_t *) &regupdate.home_addr);
@@ -580,12 +610,16 @@ void dump_mobileip(packet_t *pkt)
 	/* Display */
 	if (my_args->m)
 	  {
-
+	    display_minimal_string(map2str(mobileip_type_map, regack.type));
+	    display_minimal_string(" (");
+	    display_minimal_string("addr:");
+	    display_minimal_ipv4((u_int8_t *) &regack.home_addr);
+	    display_minimal_string(",HA:");
+	    display_minimal_ipv4((u_int8_t *) &regack.home_agent);
+	    display_minimal_string(") ");
 	  }
 	else
 	  {
-	    display_header_banner("Mobile IP");
-
 	    display_strmap("Type", regack.type, mobileip_type_map);
 	    display("Status", &regack.status, 1, DISP_HEX);
 	    display("Reserved", (u_int8_t *) &regack.reserved, 2, DISP_DEC);
@@ -597,7 +631,8 @@ void dump_mobileip(packet_t *pkt)
       }
       break;
 
-    default:
+    default: /* Unknown message type, dump the hexbuffer and quit */
+      hexbuffer_flush();
       return;
     }
 
