@@ -5,7 +5,7 @@
 **
 ** Comments: Dump OSPF information
 **
-** $Id: ospf.c,v 1.8 2000/09/27 19:27:29 mborella Exp $
+** $Id: ospf.c,v 1.10 2001/04/02 17:41:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -145,6 +145,12 @@ void dump_ospf(packet_t *pkt)
   ospf_common_header_t ospf;
   char holder[64];
   
+  /*
+   * Stats accounting
+   */
+
+  stats_update(STATS_OSPF);
+
   /*
    * Get the header
    */
@@ -168,7 +174,7 @@ void dump_ospf(packet_t *pkt)
   if (my_args->m && !my_args->n)
     {
       /* In minimal mode lets just dump the type and the router ID */
-      display_minimal_string("OSPF ");
+      display_minimal_string("| OSPF ");
       display_minimal_string(map2str(ospf_type_map, ospf.type));
       display_minimal_string(" ");      
       display_minimal_ipv4((u_int8_t *) &ospf.router_id);
