@@ -2,7 +2,7 @@
 **
 ** parse_cl.c
 **
-** Mon Mar 26 10:49:48 2001
+** Mon Apr  2 14:48:36 2001
 ** Linux 2.2.15 (#7 Wed Aug 30 18:54:13 CDT 2000) i686
 ** mborella@stratos (Mike Borella)
 **
@@ -31,7 +31,7 @@
 
 void usage(char *executable)
 {
-  printf("usage: %s [ -bcilmnprTtxhv ] \n", executable);
+  printf("usage: %s [ -bcilmnPprTtwxhv ] \n", executable);
   printf("  [ -b ] ");
   printf("(");
   printf("type=");
@@ -71,6 +71,12 @@ void usage(char *executable)
   printf("FLAG");
   printf(")\n");
   printf("         Don't print network-layer headers\n");
+  printf("  [ -P ] ");
+  printf("(");
+  printf("type=");
+  printf("STRING");
+  printf(")\n");
+  printf("         Dynamic port mapping (usage: 'protocol=port')\n");
   printf("  [ -p ] ");
   printf("(");
   printf("type=");
@@ -95,6 +101,12 @@ void usage(char *executable)
   printf("FLAG");
   printf(")\n");
   printf("         Don't print transport-layer headers\n");
+  printf("  [ -w ] ");
+  printf("(");
+  printf("type=");
+  printf("STRING");
+  printf(")\n");
+  printf("         Write the raw packets to a file\n");
   printf("  [ -x ] ");
   printf("(");
   printf("type=");
@@ -130,7 +142,9 @@ void usage(char *executable)
 void free_args(struct arg_t *my_args)
 {
   if (my_args->i != NULL) free(my_args->i);
+  if (my_args->P != NULL) free(my_args->P);
   if (my_args->r != NULL) free(my_args->r);
+  if (my_args->w != NULL) free(my_args->w);
   free(my_args);
 }
 
@@ -159,10 +173,12 @@ struct arg_t *Cmdline(int argc, char *argv[])
     {"", 0, 0, 'l'},
     {"", 0, 0, 'm'},
     {"", 0, 0, 'n'},
+    {"", 1, 0, 'P'},
     {"", 0, 0, 'p'},
     {"", 1, 0, 'r'},
     {"", 0, 0, 'T'},
     {"", 0, 0, 't'},
+    {"", 1, 0, 'w'},
     {"", 0, 0, 'x'},
     {"help", 0, 0, 'h'},
     {"version", 0, 0, 'v'},
@@ -176,15 +192,17 @@ struct arg_t *Cmdline(int argc, char *argv[])
   my_args->l = false;
   my_args->m = false;
   my_args->n = false;
+  my_args->P = NULL;
   my_args->p = false;
   my_args->r = NULL;
   my_args->T = false;
   my_args->t = false;
+  my_args->w = NULL;
   my_args->x = false;
   my_args->h = false;
   my_args->v = false;
 
-  while ((c = getopt_long(argc, argv, "bc:i:lmnpr:Ttxhv", long_options, &option_index)) != EOF)
+  while ((c = getopt_long(argc, argv, "bc:i:lmnP:pr:Ttw:xhv", long_options, &option_index)) != EOF)
     {
       switch(c)
         {
@@ -217,6 +235,10 @@ struct arg_t *Cmdline(int argc, char *argv[])
           my_args->n = true;
           break;
 
+        case 'P': 
+          my_args->P = strdup(optarg);
+          break;
+
         case 'p': 
           my_args->p = true;
           break;
@@ -233,6 +255,10 @@ struct arg_t *Cmdline(int argc, char *argv[])
           my_args->t = true;
           break;
 
+        case 'w': 
+          my_args->w = strdup(optarg);
+          break;
+
         case 'x': 
           my_args->x = true;
           break;
