@@ -2,7 +2,7 @@
 **
 ** parse_cl.h
 **
-** Mon Mar 26 10:49:48 2001
+** Mon Apr  2 14:48:36 2001
 ** Linux 2.2.15 (#7 Wed Aug 30 18:54:13 CDT 2000) i686
 ** mborella@stratos (Mike Borella)
 **
@@ -32,10 +32,12 @@ struct arg_t
   bool l;
   bool m;
   bool n;
+  char * P;
   bool p;
   char * r;
   bool T;
   bool t;
+  char * w;
   bool x;
   bool h;
   bool v;
