@@ -6,7 +6,7 @@
 **
 ** Comments: Dump TCP header information. 
 **
-** $Id: tcp.c,v 1.18 2001/04/02 17:41:01 mborella Exp $
+** $Id: tcp.c,v 1.19 2001/05/18 15:30:53 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
       /* take care of the 1-byte options */
       if (kind == TCP_OPTION_EOL || kind == TCP_OPTION_NOP)
 	{
-	  if (!my_args->m)
+	  if (!my_args->m && !my_args->t)
 	    {
 	      sprintf(holder, "%d (%s)", kind, 
 		      map2str(tcp_option_map, kind));
@@ -92,22 +92,25 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	}
 
       /* display the option's name */
-      if (!my_args->m)
+      if (!my_args->t)
 	{
-	  sprintf(holder, "%d (%s)", kind, 
-		  map2str(tcp_option_map, kind));
-	  display_string("Option", holder);
-	}
-      else 
-	{
-	  display_minimal_string("<");	  
-	  display_minimal_string(map2str(tcp_option_map, kind));
+	  if (!my_args->m)
+	    {
+	      sprintf(holder, "%d (%s)", kind, 
+		      map2str(tcp_option_map, kind));
+	      display_string("Option", holder);
+	    }
+	  else 
+	    {
+	      display_minimal_string("<");	  
+	      display_minimal_string(map2str(tcp_option_map, kind));
+	    }
 	}
       
       /* get and display the length field */
       if (get_packet_bytes((u_int8_t *) &option_length, pkt, 1) == 0)
 	return;
-      if (!my_args->m)
+      if (!my_args->m && !my_args->t)
 	display("  Length", (u_int8_t *) &option_length, 1, DISP_DEC);
       option_bytes_read += 1;
 
@@ -127,24 +130,30 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	case TCP_OPTION_MSS:
 	  memcpy((void *) &mss, holder, 2);
 	  mss = ntohs(mss);
-	  if (!my_args->m)
-	    display("  MSS", (u_int8_t *) &mss, 2, DISP_DEC);
-	  else
+	  if (!my_args->t)
 	    {
-	      display_minimal_string(" ");
-	      display_minimal((u_int8_t *) &mss, 2, DISP_DEC);
-	      display_minimal_string(">");
+	      if (!my_args->m)
+		display("  MSS", (u_int8_t *) &mss, 2, DISP_DEC);
+	      else
+		{
+		  display_minimal_string(" ");
+		  display_minimal((u_int8_t *) &mss, 2, DISP_DEC);
+		  display_minimal_string(">");
+		}
 	    }
 	  break;
 	  
 	case TCP_OPTION_WS:
-	  if (!my_args->m)
-	    display("  Shift count", (u_int8_t *) holder, 1, DISP_DEC);
-	  else
+	  if (!my_args->t)
 	    {
-	      display_minimal_string(" ");
-	      display_minimal((u_int8_t *) holder, 1, DISP_DEC);
-	      display_minimal_string(">");
+	      if (!my_args->m)
+		display("  Shift count", (u_int8_t *) holder, 1, DISP_DEC);
+	      else
+		{
+		  display_minimal_string(" ");
+		  display_minimal((u_int8_t *) holder, 1, DISP_DEC);
+		  display_minimal_string(">");
+		}
 	    }
 	  break;
 
@@ -153,23 +162,27 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	  ts1 = ntohl(ts1);
 	  memcpy((void *) &ts2, holder+4, 4);
 	  ts2 = ntohl(ts2);
-	  if (!my_args->m)
+	  if (!my_args->t)
 	    {
-	      display("  Timestamp value", (u_int8_t *) &ts1, 4, 
-		      DISP_DEC);
-	      display("  Timestamp reply", (u_int8_t *) &ts2, 4, 
-		      DISP_DEC);
-	    }
-	  else
-	    {
-	      display_minimal_string(" ");
-	      display_minimal((u_int8_t *) &ts1, 4, DISP_DEC);
-	      display_minimal_string(" ");
-	      display_minimal((u_int8_t *) &ts2, 4, DISP_DEC);
-	      display_minimal_string(">");
+	      if (!my_args->m)
+		{
+		  display("  Timestamp value", (u_int8_t *) &ts1, 4, 
+			  DISP_DEC);
+		  display("  Timestamp reply", (u_int8_t *) &ts2, 4, 
+			  DISP_DEC);
+		}
+	      else
+		{
+		  display_minimal_string(" ");
+		  display_minimal((u_int8_t *) &ts1, 4, DISP_DEC);
+		  display_minimal_string(" ");
+		  display_minimal((u_int8_t *) &ts2, 4, DISP_DEC);
+		  display_minimal_string(">");
+		}
 	    }
 	  break;
 
+	  /*
 	case 64:
 	  display_minimal_string(" ");
 	  memcpy((void *) &ts1, holder, 4);
@@ -177,9 +190,10 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	  display_minimal((u_int8_t *) &ts1, 4, DISP_DEC);
 	  display_minimal_string(">");
 	  break;
+	  */
 
 	default:
-	  if (my_args->m)
+	  if (my_args->m && !my_args->t)
 	    display_minimal_string(">");
 	  break;
 
@@ -190,7 +204,7 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
    * Trailing space for minimal mode
    */
 
-  if (my_args->m)
+  if (my_args->m && !my_args->t)
     display_minimal_string(" ");
 
 #ifdef DEBUG
